/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLElement.h"
#include "HTMLTableSectionElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLTableSectionElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLTableSectionElement.h"
#include "gdom/PrivateIntGdomHTMLElement.h"
#include "gdom/PrivateIntGdomHTMLTableSectionElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLTableSectionElement::GDOMHTMLTableSectionElement(PassRefPtr<WebCore::HTMLTableSectionElement> impl)
    : GDOMHTMLElement(impl)
{
}

GdomHTMLElement *
gdom_html_table_section_element_insert_row (GdomHTMLTableSectionElement *thiz, glong index)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::HTMLTableSectionElement * item = (gdom_html_table_section_element_get_private(thiz));
    g_return_val_if_fail (item, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::HTMLElement> g_res = WTF::getPtr(item->insertRow(index, ec));
    GdomHTMLElement * res = static_cast<GdomHTMLElement *>(WebCore::toGDOM(g_res.get()));
    return res;

}

void
gdom_html_table_section_element_delete_row (GdomHTMLTableSectionElement *thiz, glong index)
{
    g_return_if_fail (thiz);
    WebCore::HTMLTableSectionElement * item = (gdom_html_table_section_element_get_private(thiz));
    g_return_if_fail (item);
    WebCore::ExceptionCode ec = 0;
    item->deleteRow(index, ec);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLTableSectionElement.h"
#include <gdom/GdomHTMLTableSectionElement.h>
#include <gdom/PrivateGdomHTMLTableSectionElement.h>
#include <gdom/PrivateIntGdomHTMLTableSectionElement.h>
#include <gdom/GdomHTMLTableSectionElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLTableSectionElement, gdom_html_table_section_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLTableSectionElementPrivate {
    class WebCore::HTMLTableSectionElement *item;
};

#define GDOM_HTML_TABLE_SECTION_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_TABLE_SECTION_ELEMENT, GdomHTMLTableSectionElementPrivate))
*/
G_END_DECLS
WebCore::HTMLTableSectionElement *
gdom_html_table_section_element_get_private(GdomHTMLTableSectionElement *request)
{
    GDOMHTMLTableSectionElement *res;
    res = static_cast<GDOMHTMLTableSectionElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLTableSectionElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_ALIGN,
    PROP_CH,
    PROP_CH_OFF,
    PROP_V_ALIGN,
    PROP_ROWS,
};


static void gdom_html_table_section_element_finalize(GObject* object)
{
    /*GdomHTMLTableSectionElement* request = GDOM_HTML_TABLE_SECTION_ELEMENT(object);*/
    /*GdomHTMLTableSectionElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_table_section_element_parent_class)->finalize(object);
}

static void gdom_html_table_section_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableSectionElement *self = GDOM_HTML_TABLE_SECTION_ELEMENT(object);
    WebCore::HTMLTableSectionElement * gself = (gdom_html_table_section_element_get_private(self));
    switch (prop_id) {
     case PROP_ALIGN:
    {
         gself->setAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH:
    {
         gself->setCh(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH_OFF:
    {
         gself->setChOff(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_V_ALIGN:
    {
         gself->setVAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_section_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableSectionElement *self = GDOM_HTML_TABLE_SECTION_ELEMENT(object);
    WebCore::HTMLTableSectionElement * gself = (gdom_html_table_section_element_get_private(self));
    switch (prop_id) {
    case PROP_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->align()));
         break;
    }
    case PROP_CH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->ch()));
         break;
    }
    case PROP_CH_OFF:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->chOff()));
         break;
    }
    case PROP_V_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->vAlign()));
         break;
    }
    case PROP_ROWS:
    {
         PassRefPtr<WebCore::HTMLCollection> ptr = gself->rows();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_section_element_class_init(GdomHTMLTableSectionElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_table_section_element_finalize;
    g_klass->set_property = gdom_html_table_section_element__set_property_fn;
    g_klass->get_property = gdom_html_table_section_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_ALIGN,
            g_param_spec_string ("align", /* name */
                "html_table_section_element_align", /* short description */
                "read-write  gchar * HTMLTableSectionElement.align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH,
            g_param_spec_string ("ch", /* name */
                "html_table_section_element_ch", /* short description */
                "read-write  gchar * HTMLTableSectionElement.ch", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH_OFF,
            g_param_spec_string ("ch_off", /* name */
                "html_table_section_element_ch_off", /* short description */
                "read-write  gchar * HTMLTableSectionElement.ch_off", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_V_ALIGN,
            g_param_spec_string ("v_align", /* name */
                "html_table_section_element_v_align", /* short description */
                "read-write  gchar * HTMLTableSectionElement.v_align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ROWS,
            g_param_spec_object ("rows", /* name */
                "html_table_section_element_rows", /* short description */
                "read-only  GdomHTMLCollection * HTMLTableSectionElement.rows", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_COLLECTION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLTableSectionElementPrivate));*/
}

static void gdom_html_table_section_element_init(GdomHTMLTableSectionElement* request)
{
    /*GdomHTMLTableSectionElementPrivate* priv = GDOM_HTML_TABLE_SECTION_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

